import { asyncDelay, playAudioByUrl, asyncGetSpriteFrimeByUrl, buttonOnClick } from "../script/util";
import { MyCocosSceneComponent } from "../script/MyCocosSceneComponent";

const { ccclass, property } = cc._decorator;

@ccclass
export default class SceneComponent extends MyCocosSceneComponent {

    addPreloadImage() {
        this._imageResList.push({ url: this.data.bookImg });
    }

    addPreloadAudio() {
        this._audioResList.push({ url: this.data.questionTextAudio });
        this._audioResList.push({ url: this.data.bookAudio });
    }

    addPreloadAnima() {

    }

    async onLoadEnd() {
        await this.initView();
        this.initListener();
    }

    async initView() {
        const levelNode = cc.find(`Canvas/bg/L${this.data.choseLevel}`);
        if(!levelNode) {
            return;
        }
        levelNode.active = true;
        cc.find(`box/title`, levelNode).getComponent(cc.Label).string = this.data.title;

        try {
            const bookImgFrame:any = await asyncGetSpriteFrimeByUrl(this.data.bookImg);
            cc.find(`Canvas/bg/bookImg/img`).getComponent(cc.Sprite).spriteFrame = bookImgFrame;
        } catch (error) {
            console.error(error);
        }
    }
    

    initListener() {
        const bgButton = cc.find(`Canvas/bg/bookImg`);
        bgButton.on('click', () => {
            playAudioByUrl(this.data.bookAudio);
        });

        const levelNode = cc.find(`Canvas/bg/L${this.data.choseLevel}`);
        if(!levelNode) {
            return;
        }
        const levelButton = cc.find(`box`, levelNode);
        levelButton.on('click', ()=>{
            if (levelButton['cantClick']) {
                return;
            }
            levelButton['cantClick'] = true;
            // TODO 播放骨骼动画
            playAudioByUrl(this.data.questionTextAudio, ()=>{
                // TODO 更新骨骼动画状态
                levelButton['cantClick'] = false;
            });
        })
       
        buttonOnClick(cc.find(`kdh`, levelNode), () => {
            // TODO 跳转到看动画（第一个课件）
        });
        buttonOnClick(cc.find(`dgs`, levelNode), () => {
            // TODO 跳转到读故事（第二个课件）
        });
        buttonOnClick(cc.find(`qpy`, levelNode), () => {
            // TODO 跳转到趣配音（第三个课件）
        });
    }

   
}
